@@ -1,7 +1,6 @@
 /*
     Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
     Copyright (c) 2009 Andras Mantia <amantia@kde.org>
-    Copyright (c) 2017 Christian Mollekopf <mollekopf@kolabsys.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -19,22 +18,21 @@
     02110-1301, USA.
 */
 
-#ifndef KIMAP2_LOGINJOB_H
-#define KIMAP2_LOGINJOB_H
+#ifndef KIMAP_LOGINJOB_H
+#define KIMAP_LOGINJOB_H
 
-#include "kimap2_export.h"
+#include "kimap_export.h"
 
 #include "job.h"
-#include <QtNetwork/QSsl>
 
-namespace KIMAP2
+namespace KIMAP
 {
 
 class Session;
 struct Message;
 class LoginJobPrivate;
 
-class KIMAP2_EXPORT LoginJob : public Job
+class KIMAP_EXPORT LoginJob : public Job
 {
     Q_OBJECT
     Q_DECLARE_PRIVATE(LoginJob)
@@ -42,6 +40,14 @@ class KIMAP2_EXPORT LoginJob : public Job
     friend class SessionPrivate;
 
 public:
+    enum EncryptionMode {
+        Unencrypted = 0,
+        TlsV1,
+        SslV2,
+        SslV3,
+        SslV3_1,
+        AnySslVersion
+    };
 
     enum AuthenticationMode {
         ClearText = 0,
@@ -55,6 +61,10 @@ public:
         XOAuth2
     };
 
+    enum ErrorCode {
+        ERR_COULD_NOT_CONNECT = KJob::UserDefinedError + 23 // same as in kio
+    };
+
     explicit LoginJob(Session *session);
     virtual ~LoginJob();
 
@@ -100,13 +110,13 @@ public:
      * encrypted or not (e.g handshaking failed).
      * @param mode the encryption mode, see EncryptionModes
      */
-    void setEncryptionMode(QSsl::SslProtocol mode, bool startTls = false);
+    void setEncryptionMode(EncryptionMode mode);
 
     /**
       Get the encryption mode.
       @return the currently active encryption mode
     */
-    QSsl::SslProtocol encryptionMode();
+    EncryptionMode encryptionMode();
 
     void setAuthenticationMode(AuthenticationMode mode);
 
