@@ -20,40 +20,16 @@
 #include "namespacejob.h"
 
 #include "kimap_debug.h"
+#include <KLocalizedString>
 
 #include "job_p.h"
 #include "listjob.h"
 #include "message_p.h"
 #include "rfccodecs.h"
 #include "session_p.h"
+#include "imapstreamparser.h"
 
-static QList<QByteArray> parseParenthesizedList(const QByteArray &data)
-{
-    QList<QByteArray> result;
-    if (data.isEmpty()) {
-        return result;
-    }
-    if (data.at(0) != '(') {
-        return result;
-    }
-    bool parsingString = false;
-    int start = 0;
-    for (int pos = 1; pos < data.size(); pos++) {
-        //Match unescaped quotes
-        if (data.at(pos) == '\"' && data.at(pos - 1) != '\\') {
-            if (parsingString) {
-                parsingString = false;
-                result << data.mid(start, pos - start);
-            } else {
-                parsingString = true;
-                start = pos + 1;
-            }
-        }
-    }
-    return result;
-}
-
-namespace KIMAP2
+namespace KIMAP
 {
 class NamespaceJobPrivate : public JobPrivate
 {
@@ -66,16 +42,24 @@ public:
         QList<MailBoxDescriptor> result;
 
         foreach (const QByteArray &namespaceItem, namespaceList) {
-            QList<QByteArray> parts = parseParenthesizedList(namespaceItem);
-            if (parts.size() < 2) {
-                qWarning() << "Not enough parts in namespace item " << namespaceItem;
-                continue;
+            ImapStreamParser parser(Q_NULLPTR);
+            parser.setData(namespaceItem);
+
+            try {
+                QList<QByteArray> parts = parser.readParenthesizedList();
+                if (parts.size() < 2) {
+                    continue;
+                }
+                MailBoxDescriptor descriptor;
+                descriptor.name = QString::fromUtf8(decodeImapFolderName(parts[0]));
+                descriptor.separator = QLatin1Char(parts[1][0]);
+
+                result << descriptor;
+            } catch (KIMAP::ImapParserException e) {
+                qCWarning(KIMAP_LOG) << "The stream parser raised an exception during namespace list parsing:" << e.what();
+                qCWarning(KIMAP_LOG) << "namespacelist:" << namespaceList;
             }
-            MailBoxDescriptor descriptor;
-            descriptor.name = QString::fromUtf8(decodeImapFolderName(parts[0]));
-            descriptor.separator = QLatin1Char(parts[1][0]);
 
-            result << descriptor;
         }
 
         return result;
@@ -87,10 +71,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 NamespaceJob::NamespaceJob(Session *session)
-    : Job(*new NamespaceJobPrivate(session, "Namespace"))
+    : Job(*new NamespaceJobPrivate(session, i18n("Namespace")))
 {
 }
 
@@ -135,7 +119,7 @@ bool NamespaceJob::containsEmptyNamespace() const
 void NamespaceJob::doStart()
 {
     Q_D(NamespaceJob);
-    d->sendCommand("NAMESPACE", {});
+    d->tags << d->sessionInternal()->sendCommand("NAMESPACE");
 }
 
 void NamespaceJob::handleResponse(const Message &response)
